# lifeguard-telegram

Lifeguard Telegram Integration

## Example

A valid example can be found in [https://github.com/diegorubin/lifeguard/blob/main/validations/pods_validation.py](https://github.com/diegorubin/lifeguard/blob/main/validations/pods_validation.py).

Screenshot with the example output:

![Example output](./docs/example-k8s.png)

